@@ -1,7 +1,7 @@
 package Text::Table::Any;
 
 our $DATE = '2016-09-03'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 #IFUNBUILT
 # # use 5.010001;
@@ -17,18 +17,19 @@ sub _encode {
 
 sub table {
     my %params = @_;
-    my $rows = $params{rows} or die "Must provide rows!";
 
-    my $backend = $params{backend} || 'Text::Table::Tiny';
+    my $rows       = $params{rows} or die "Must provide rows!";
+    my $backend    = $params{backend} || 'Text::Table::Tiny';
+    my $header_row = $params{header_row} // 0;
 
     if ($backend eq 'Text::Table::Tiny') {
         require Text::Table::Tiny;
         return Text::Table::Tiny::table(
-            rows => $rows, header_row => $params{header_row}) . "\n";
+            rows => $rows, header_row => $header_row) . "\n";
     } elsif ($backend eq 'Text::Table::Org') {
         require Text::Table::Org;
         return Text::Table::Org::table(
-            rows => $rows, header_row => $params{header_row});
+            rows => $rows, header_row => $header_row);
     } elsif ($backend eq 'Text::Table::CSV') {
         require Text::Table::CSV;
         return Text::Table::CSV::table(
@@ -39,21 +40,26 @@ sub table {
             use_utf8 => 0,
             use_box_chars => 0,
             use_color => 0,
-            columns => $rows->[0],
             border_style => 'Default::single_ascii',
         );
         # XXX pick an appropriate border style when header_row=0
-        $t->add_row($rows->[$_]) for 1..@$rows-1;
+        if ($header_row) {
+            $t->columns($rows->[0]);
+            $t->add_row($rows->[$_]) for 1..@$rows-1;
+        } else {
+            $t->columns([ map {"col$_"} 0..$#{$rows->[0]} ]);
+            $t->add_row($_) for @$rows;
+        }
         return $t->draw;
     } elsif ($backend eq 'Text::ASCIITable') {
         require Text::ASCIITable;
         my $t = Text::ASCIITable->new();
-        if ($params{header_row}) {
+        if ($header_row) {
             $t->setCols(@{ $rows->[0] });
             $t->addRow(@{ $rows->[$_] }) for 1..@$rows-1;
         } else {
             $t->setCols(map { "col$_" } 0..$#{ $rows->[0] });
-            $t->addRow(@{ $rows->[$_] }) for 0..$#{$rows};
+            $t->addRow(@$_) for @$rows;
         }
         return "$t";
     } elsif ($backend eq 'Text::FormatTable') {
@@ -65,9 +71,10 @@ sub table {
     } elsif ($backend eq 'Text::MarkdownTable') {
         require Text::MarkdownTable;
         my $out = "";
-        my $t = Text::MarkdownTable->new(file => \$out);
-        my $fields = $rows->[0];
-        foreach (1..@$rows-1) {
+        my $fields =  $header_row ?
+            $rows->[0] : [map {"col$_"} 0..$#{ $rows->[0] }];
+        my $t = Text::MarkdownTable->new(file => \$out, columns => $fields);
+        foreach (($header_row ? 1:0) .. $#{$rows}) {
             my $row = $rows->[$_];
             $t->add( {
                 map { $fields->[$_] => $row->[$_] } 0..@$fields-1
@@ -105,7 +112,7 @@ Text::Table::Any - Generate text table using one of several backends
 
 =head1 VERSION
 
-This document describes version 0.02 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2016-09-03.
+This document describes version 0.03 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2016-09-03.
 
 =head1 SYNOPSIS
 
